@@ -119,7 +119,8 @@ used by LLaMA, Mistral, and similar models:
 =head2 new
 
     my $inference = Lugh::Inference->new(
-        model => $model
+        model      => $model,
+        flash_attn => 0,  # optional, use flash attention
     );
 
 Creates a new Inference engine from a loaded model.
@@ -130,6 +131,8 @@ B<Parameters:>
 
 =item * C<model> (required) - A Lugh::Model object
 
+=item * C<flash_attn> (optional) - Use flash attention if set to 1 (default: 0)
+
 =back
 
 B<Returns:> A Lugh::Inference object.
@@ -140,6 +143,12 @@ B<Example:>
 
     my $model = Lugh::Model->new(model => 'model.gguf');
     my $inference = Lugh::Inference->new(model => $model);
+    
+    # Or with flash attention enabled
+    my $fast_inference = Lugh::Inference->new(
+        model      => $model,
+        flash_attn => 1,
+    );
 
 =head1 METHODS
 
